==> cr12g-panhuo-impl-3.0.0-20210510.094139-7-sources.jar: com/ejianc/business/asset/bean/MaterialDealDetailEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 报废处置子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_material_deal_detail")
public class MaterialDealDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="p_id")
    private Long pId; // 父主键
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资分类名称
    @TableField(value="material_type_code")
    private String materialTypeCode; // 物资分类编码
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资分类Id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_code")
    private String materialCode; // 物资code
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="asset_id")
    private Long assetId; // 资产id
    @TableField(value="asset_type")
    private Integer assetType; // 0台车1周转材
    @TableField(value="asset_name")
    private String assetName; // 台车/周转材
    @TableField(value="asset_code")
    private String assetCode; // 编码
    @TableField(value="org_id")
    private Long orgId; // 组织Id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="ton")
    private java.math.BigDecimal ton; // 承载量（吨)
    @TableField(value="on_num")
    private java.math.BigDecimal onNum; // 在场数量
    @TableField(value="deal_num")
    private java.math.BigDecimal dealNum; // 处置数量
    @TableField(value="deal_price")
    private java.math.BigDecimal dealPrice; // 处置单价
    @TableField(value="deal_money")
    private java.math.BigDecimal dealMoney; // 处置金额
    @TableField(value="belong_type")
    private Integer belongType; // 0项目1公司
    @TableField(value="asset_belong_type")
    private Integer assetBelongType; // 资产归属类型
    @TableField(value="belong_org_id")
    private Long belongOrgId; // 资产归属机构id
    @TableField(value="belong_org_name")
    private String belongOrgName; // 资产归属机构名称
    
    
    

    /**
     * 父主键
     */
    public Long getPId() {
        return pId;
    }

    /**
     * 父主键
     */
    public void setPId(Long pId) {
        this.pId = pId;
    }
    /**
     * 物资分类名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资分类名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资分类编码
     */
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    /**
     * 物资分类编码
     */
    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    /**
     * 物资分类Id
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资分类Id
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资code
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物资code
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 物资Id
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资Id
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 计量单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 资产id
     */
    public Long getAssetId() {
        return assetId;
    }

    /**
     * 资产id
     */
    public void setAssetId(Long assetId) {
        this.assetId = assetId;
    }
    /**
     * 0台车1周转材
     */
    public Integer getAssetType() {
        return assetType;
    }

    /**
     * 0台车1周转材
     */
    public void setAssetType(Integer assetType) {
        this.assetType = assetType;
    }
    /**
     * 台车/周转材
     */
    public String getAssetName() {
        return assetName;
    }

    /**
     * 台车/周转材
     */
    public void setAssetName(String assetName) {
        this.assetName = assetName;
    }
    /**
     * 编码
     */
    public String getAssetCode() {
        return assetCode;
    }

    /**
     * 编码
     */
    public void setAssetCode(String assetCode) {
        this.assetCode = assetCode;
    }
    /**
     * 组织Id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织Id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 承载量（吨)
     */
    public java.math.BigDecimal getTon() {
        return ton;
    }

    /**
     * 承载量（吨)
     */
    public void setTon(java.math.BigDecimal ton) {
        this.ton = ton;
    }
    /**
     * 在场数量
     */
    public java.math.BigDecimal getOnNum() {
        return onNum;
    }

    /**
     * 在场数量
     */
    public void setOnNum(java.math.BigDecimal onNum) {
        this.onNum = onNum;
    }
    /**
     * 处置数量
     */
    public java.math.BigDecimal getDealNum() {
        return dealNum;
    }

    /**
     * 处置数量
     */
    public void setDealNum(java.math.BigDecimal dealNum) {
        this.dealNum = dealNum;
    }
    /**
     * 处置单价
     */
    public java.math.BigDecimal getDealPrice() {
        return dealPrice;
    }

    /**
     * 处置单价
     */
    public void setDealPrice(java.math.BigDecimal dealPrice) {
        this.dealPrice = dealPrice;
    }
    /**
     * 处置金额
     */
    public java.math.BigDecimal getDealMoney() {
        return dealMoney;
    }

    /**
     * 处置金额
     */
    public void setDealMoney(java.math.BigDecimal dealMoney) {
        this.dealMoney = dealMoney;
    }
    /**
     * 0项目1公司
     */
    public Integer getBelongType() {
        return belongType;
    }

    /**
     * 0项目1公司
     */
    public void setBelongType(Integer belongType) {
        this.belongType = belongType;
    }
    /**
     * 资产归属类型
     */
    public Integer getAssetBelongType() {
        return assetBelongType;
    }

    /**
     * 资产归属类型
     */
    public void setAssetBelongType(Integer assetBelongType) {
        this.assetBelongType = assetBelongType;
    }
    /**
     * 资产归属机构id
     */
    public Long getBelongOrgId() {
        return belongOrgId;
    }

    /**
     * 资产归属机构id
     */
    public void setBelongOrgId(Long belongOrgId) {
        this.belongOrgId = belongOrgId;
    }
    /**
     * 资产归属机构名称
     */
    public String getBelongOrgName() {
        return belongOrgName;
    }

    /**
     * 资产归属机构名称
     */
    public void setBelongOrgName(String belongOrgName) {
        this.belongOrgName = belongOrgName;
    }
    
}

==> cr12g-panhuo-impl-3.0.0-20210609.062335-78-sources.jar: com/ejianc/business/asset/bean/MaterialDealDetailEntity.java <==
package com.ejianc.business.asset.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 报废处置子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_panhuo_material_deal_detail")
public class MaterialDealDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="p_id")
    private Long pId; // 父主键
    @TableField(value="material_type_name")
    private String materialTypeName; // 物资分类名称
    @TableField(value="material_type_code")
    private String materialTypeCode; // 物资分类编码
    @TableField(value="material_type_id")
    private Long materialTypeId; // 物资分类Id
    @TableField(value="material_name")
    private String materialName; // 物资名称
    @TableField(value="material_code")
    private String materialCode; // 物资code
    @TableField(value="material_id")
    private Long materialId; // 物资Id
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit")
    private String unit; // 计量单位
    @TableField(value="asset_id")
    private Long assetId; // 资产id
    @TableField(value="asset_type")
    private Integer assetType; // 0台车1周转材
    @TableField(value="asset_name")
    private String assetName; // 台车/周转材
    @TableField(value="asset_code")
    private String assetCode; // 编码
    @TableField(value="org_id")
    private Long orgId; // 组织Id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="ton")
    private java.math.BigDecimal ton; // 承载量（吨)
    @TableField(value="on_num")
    private java.math.BigDecimal onNum; // 在场数量
    @TableField(value="deal_num")
    private java.math.BigDecimal dealNum; // 处置数量
    @TableField(value="deal_price")
    private java.math.BigDecimal dealPrice; // 处置单价
    @TableField(value="deal_money")
    private java.math.BigDecimal dealMoney; // 处置金额
    @TableField(value="belong_type")
    private Integer belongType; // 0项目1公司
    @TableField(value="asset_belong_type")
    private Integer assetBelongType; // 资产归属类型
    @TableField(value="belong_org_id")
    private Long belongOrgId; // 资产归属机构id
    @TableField(value="belong_org_name")
    private String belongOrgName; // 资产归属机构名称
    @TableField(value="material_remark")
    private String materialRemark; // 备注


    public String getMaterialRemark() {
        return materialRemark;
    }

    public void setMaterialRemark(String materialRemark) {
        this.materialRemark = materialRemark;
    }

    /**
     * 父主键
     */
    public Long getPId() {
        return pId;
    }

    /**
     * 父主键
     */
    public void setPId(Long pId) {
        this.pId = pId;
    }
    /**
     * 物资分类名称
     */
    public String getMaterialTypeName() {
        return materialTypeName;
    }

    /**
     * 物资分类名称
     */
    public void setMaterialTypeName(String materialTypeName) {
        this.materialTypeName = materialTypeName;
    }
    /**
     * 物资分类编码
     */
    public String getMaterialTypeCode() {
        return materialTypeCode;
    }

    /**
     * 物资分类编码
     */
    public void setMaterialTypeCode(String materialTypeCode) {
        this.materialTypeCode = materialTypeCode;
    }
    /**
     * 物资分类Id
     */
    public Long getMaterialTypeId() {
        return materialTypeId;
    }

    /**
     * 物资分类Id
     */
    public void setMaterialTypeId(Long materialTypeId) {
        this.materialTypeId = materialTypeId;
    }
    /**
     * 物资名称
     */
    public String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    /**
     * 物资code
     */
    public String getMaterialCode() {
        return materialCode;
    }

    /**
     * 物资code
     */
    public void setMaterialCode(String materialCode) {
        this.materialCode = materialCode;
    }
    /**
     * 物资Id
     */
    public Long getMaterialId() {
        return materialId;
    }

    /**
     * 物资Id
     */
    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    /**
     * 规格型号
     */
    public String getSpec() {
        return spec;
    }

    /**
     * 规格型号
     */
    public void setSpec(String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public String getUnit() {
        return unit;
    }

    /**
     * 计量单位
     */
    public void setUnit(String unit) {
        this.unit = unit;
    }
    /**
     * 资产id
     */
    public Long getAssetId() {
        return assetId;
    }

    /**
     * 资产id
     */
    public void setAssetId(Long assetId) {
        this.assetId = assetId;
    }
    /**
     * 0台车1周转材
     */
    public Integer getAssetType() {
        return assetType;
    }

    /**
     * 0台车1周转材
     */
    public void setAssetType(Integer assetType) {
        this.assetType = assetType;
    }
    /**
     * 台车/周转材
     */
    public String getAssetName() {
        return assetName;
    }

    /**
     * 台车/周转材
     */
    public void setAssetName(String assetName) {
        this.assetName = assetName;
    }
    /**
     * 编码
     */
    public String getAssetCode() {
        return assetCode;
    }

    /**
     * 编码
     */
    public void setAssetCode(String assetCode) {
        this.assetCode = assetCode;
    }
    /**
     * 组织Id
     */
    public Long getOrgId() {
        return orgId;
    }

    /**
     * 组织Id
     */
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    /**
     * 项目id
     */
    public Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    /**
     * 承载量（吨)
     */
    public java.math.BigDecimal getTon() {
        return ton;
    }

    /**
     * 承载量（吨)
     */
    public void setTon(java.math.BigDecimal ton) {
        this.ton = ton;
    }
    /**
     * 在场数量
     */
    public java.math.BigDecimal getOnNum() {
        return onNum;
    }

    /**
     * 在场数量
     */
    public void setOnNum(java.math.BigDecimal onNum) {
        this.onNum = onNum;
    }
    /**
     * 处置数量
     */
    public java.math.BigDecimal getDealNum() {
        return dealNum;
    }

    /**
     * 处置数量
     */
    public void setDealNum(java.math.BigDecimal dealNum) {
        this.dealNum = dealNum;
    }
    /**
     * 处置单价
     */
    public java.math.BigDecimal getDealPrice() {
        return dealPrice;
    }

    /**
     * 处置单价
     */
    public void setDealPrice(java.math.BigDecimal dealPrice) {
        this.dealPrice = dealPrice;
    }
    /**
     * 处置金额
     */
    public java.math.BigDecimal getDealMoney() {
        return dealMoney;
    }

    /**
     * 处置金额
     */
    public void setDealMoney(java.math.BigDecimal dealMoney) {
        this.dealMoney = dealMoney;
    }
    /**
     * 0项目1公司
     */
    public Integer getBelongType() {
        return belongType;
    }

    /**
     * 0项目1公司
     */
    public void setBelongType(Integer belongType) {
        this.belongType = belongType;
    }
    /**
     * 资产归属类型
     */
    public Integer getAssetBelongType() {
        return assetBelongType;
    }

    /**
     * 资产归属类型
     */
    public void setAssetBelongType(Integer assetBelongType) {
        this.assetBelongType = assetBelongType;
    }
    /**
     * 资产归属机构id
     */
    public Long getBelongOrgId() {
        return belongOrgId;
    }

    /**
     * 资产归属机构id
     */
    public void setBelongOrgId(Long belongOrgId) {
        this.belongOrgId = belongOrgId;
    }
    /**
     * 资产归属机构名称
     */
    public String getBelongOrgName() {
        return belongOrgName;
    }

    /**
     * 资产归属机构名称
     */
    public void setBelongOrgName(String belongOrgName) {
        this.belongOrgName = belongOrgName;
    }
    
}
